/*
 *  Sample C   -- header file for simulation
 */

#define OP_ALU     1     /*  ALU    aritmetic-logic-op   */
#define OP_DEC     2     /*  DEC    region, offset       */
#define OP_INC     3     /*  INC    region, offset       */
#define OP_LOAD    4     /*  LOAD   region, offset       */
#define OP_STORE   5     /*  STORE  region, offset       */
#define OP_POP     6     /*  POP                         */
#define OP_JUMPZ   7     /*  JUMPZ  label                */
#define OP_JUMP    8     /*  JUMP   label                */
#define OP_CALL    9     /*  CALL   param-count, address */
#define OP_ENTRY   10    /*  ENTRY  local-frame-size     */
#define OP_RETURN  11    /*  RET                         */

/*
 *  region modifiers
 */

#define MOD_GLOBAL  1      /* gbl global region        */
#define MOD_PARAM   2      /* par parameter region     */
#define MOD_LOCAL   3      /* lcl local region         */
#define MOD_IMMED   4      /* con load only: constant  */

/*
 *  OP_ALU modifiers
 */

#define ALU_ADD  1          /*  addition            */
#define ALU_SUB  2          /*  subtraction         */
#define ALU_MUL  3          /*  multiplication      */
#define ALU_DIV  4          /*  division            */
#define ALU_MOD  5          /*  remainder           */
#define ALU_LT   6          /*  compares as : <     */
#define ALU_GT   7          /*                >     */
#define ALU_LE   8          /*                <=    */
#define ALU_GE   9          /*                >=    */
#define ALU_EQ   10         /*                ==    */
#define ALU_NE   11         /*                !=    */
#define ALU_AND  12         /*  bit-wise and        */
#define ALU_OR   13         /*  bit-wise or         */
#define ALU_XOR  14         /*  bit-wise excl. or   */


/*
 *  program memory structure
 */

struct prog {
  short OP;                 /* operation code */
  short mod;                /* modifier */
  int   val;                /* offset or other value */
};

/*
 *  tunable limits
 */

#define PROG 200             /* max prog size */
#define DATA 100             /* max area for stack, etc. */
